@@ -3,14 +3,16 @@ package Dist::Zilla::Plugin::Author::Plicease::Tests;
 use strict;
 use warnings;
 use Moose;
+use File::chdir;
 use File::Path qw( make_path );
-use Dist::Zilla::MintingProfile::Plicease;
+use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only relese tests to xt/release
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '0.94'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeBuild';
+with 'Dist::Zilla::Role::BeforeRelease';
 
 has source => (
   is      =>'ro',
@@ -37,7 +39,7 @@ sub before_build
   
   my $source = defined $self->source
   ? $self->zilla->root->subdir($self->source)
-  : Dist::Zilla::MintingProfile::Plicease->profile_dir->subdir(qw( default skel xt release ));
+  : Dist::Zilla::MintingProfile::Author::Plicease->profile_dir->subdir(qw( default skel xt release ));
 
   foreach my $t_file (grep { $_->basename =~ /\.t$/ } $source->children(no_hidden => 1))
   {
@@ -61,9 +63,22 @@ sub before_build
   }
 }
 
+sub before_release
+{
+  my($self) = @_;
+  
+  my $build_root = $self->zilla->built_in;
+  $self->log("prove release tests in $build_root");
+  local $CWD = $build_root;
+  system 'prove', '-lr', 'xt';
+  
+  $self->log_fatal('release test failure') unless $? == 0;
+}
+
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -72,7 +87,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only relese tests to x
 
 =head1 VERSION
 
-version 0.93
+version 0.94
 
 =head1 SYNOPSIS
 
@@ -92,4 +107,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
